@@ -1,7 +1,19 @@
-/*
- * 	Copyright 1988 University Corporation for Atmospheric Research
- *      See netcdf/COPYRIGHT file for copying and redistribution conditions.
- */
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright 1988, University Corporation for Atmospheric Research           *
+ * See netcdf/COPYRIGHT file for copying and redistribution conditions.      *
+ *                                                                           *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+
 static char mrcsid[] = "Id: cdftest.c,v 1.11 1994/01/10 23:07:27 chouck Exp ";
 
 /*
@@ -19,7 +31,13 @@ static char mrcsid[] = "Id: cdftest.c,v 1.11 1994/01/10 23:07:27 chouck Exp ";
 /* #define SYNCDEBUG */
 /* #define NOBUF */
 #include <stdio.h>
+#include "h4config.h"
+#ifdef H4_HAVE_NETCDF
 #include "netcdf.h"
+#else
+#include "hdf4_netcdf.h"
+#endif
+
 #ifdef HDF
 #include "hdf.h"
 #endif
@@ -34,13 +52,9 @@ static char mrcsid[] = "Id: cdftest.c,v 1.11 1994/01/10 23:07:27 chouck Exp ";
 #define CDFMAXLONG		2147483647
 #define  CDFMAXBYTE	127
 
-/*   #ifdef PC  */
-/* For CRAYMPP, an explicit include <errno.h> uses the task-local memory */
-/* errno.  Read the CRAYMPP errno.h for more explanation. */
-#if defined PC || (defined VMS) || (defined CRAYMPP)
 #include <errno.h>
-#else
-extern int errno ;
+#if defined ERRNO_MISSING
+extern int errno;
 #endif
 
 #define FILENAME		"test.cdf"
@@ -59,15 +73,15 @@ struct {
 } cdesc[1] ;
 
 struct {
-	char mnem[MAX_NC_NAME] ;
+	char mnem[H4_MAX_NC_NAME] ;
 	nc_type type ;
 	int ndims ;
-	int dims[MAX_VAR_DIMS] ;
+	int dims[H4_MAX_VAR_DIMS] ;
 	int num_attrs ;
 } vdesc[1] ;
 
 struct {
-	char mnem[MAX_NC_NAME] ;
+	char mnem[H4_MAX_NC_NAME] ;
 	nc_type type ;
 	int len ;
 } adesc[1] ;
@@ -137,7 +151,7 @@ const char *dim_names[] ;
 {
 	int ii ;
 	long size ;
-	char cp[MAX_NC_NAME] ;
+	char cp[H4_MAX_NC_NAME] ;
 	for(ii=0 ; ii < num_dims ; ii++, sizes++)
 	{
 		assert( ncdiminq(cdfid, ii, cp, &size) >= 0) ;
@@ -261,7 +275,7 @@ int id ;
 	/* zero the indices */
 
 	cc = vindices;
-	while (cc < &vindices[num_dims])
+	while (cc <= &vindices[num_dims-1])
 		*cc++ = 0; 
 
 	/* ripple counter */
@@ -306,7 +320,7 @@ int id ;
 
 	sizes[0] = NUM_RECS ;
 	cc = vindices;
-	while (cc < &vindices[num_dims])
+	while (cc <= &vindices[num_dims-1])
 		*cc++ = 0; 
 
 	/* ripple counter */
@@ -702,7 +716,7 @@ char *argv[];
 	printf("got val = %c (0x%02x) \n", got.by[0], got.by[0] ) ;
 
 	/* (void)memset(new,0,256) ; */
-	{ char *cp = new; for(; cp < &new[sizeof(new)] ; *cp++ = 0) ; }
+	{ char *cp = new; for(; cp < &new[sizeof(new)-1] ; *cp++ = 0) ; }
 	assert( ncvarget(id, Byte_id, s_start, s_edges, (ncvoid *)new) != -1 ) ;
 	printf("got val = \"%s\"\n", new) ;
 
